.alc__root {
  background-color: #007d7e;
}

.alc__list-controls {
  padding: 0 50px 20px 50px;
}

.alc__panel {
  background: white;
  padding: 20px;
  margin-top: 20px;
}

.alc__panel.is-collapsed {
  display: none;
}

.alc__button {
  background-color: #00676a;
}

.alc__button:hover,
.alc__button:active,
.alc__button:focus {
  background-color: #00585a;
}

.alc__button.is-selected {
  background-color: darken(#00676a, 8);
}

.alc__button.is-selected .alc__text {
  text-decoration: underline;
}

.alc__text + .alc__button {
  margin-left: 20px;
}

.alc__text--size-large {
  font-size: 20px;
}

.alc__icon + .alc__text {
  margin-left: 3px;
}

.alc__text + .alc__icon {
  margin-left: 3px;
}

// Collapse/expand icons in buttons
.alc__icon--panel-toggle {
  display: inline-block;
  width: 15px;
  line-height: 18px;
  font-size: 18px;
}

.alc__filter {
  display: block;
  margin-bottom: 15px;
  vertical-align: top;
}

.alc__text + .alc__filter {
  margin-top: 15px;
}

.alc__filter__label {
  display: block;
  width: 100%;
  padding: 0;
  float: none;
}

.alc__filter--text .alc__filter__input {
  padding: .4em 1em;
}

.alc__filter--radio .alc__filter__input-wrap {
  padding-top: 10px;
}

.alc__filter__radio-choice {
  display: inline-block;
  margin-bottom: 16px;
}

.alc__filter__radio-choice__label {
  padding: 0;
  float: none;
  width: auto;
  display: inline-block;
  margin-right: 25px;
}

.alc__filter__radio-choice__text {
  display: inline-block;
  position: relative;
  top: 2px;
  padding-left: 5px;
  font-weight: normal;
}

.alc__filter--boolean .alc__filter__input-wrap {
  margin-top: 10px;
}

.alc__filter--choice .alc__filter__input-wrap {
  padding-top: 5px;
}

.alc__summary {
  margin: 20px 0 10px 0;
}

.alc__summary__detail {
  display: inline-block;
  margin-right: 5px;
  margin-bottom: 5px;
}

.alc__summary__detail__button {
  padding: 5px 10px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, .35);
  background: transparent;
  color: white;
  font-size: 13px;
}

.alc__summary__detail__button:hover,
.alc__summary__detail__button:active,
.alc__summary__detail__button:focus {
  background-color: #00676a;
}

.alc__summary__detail__icon {
  position: relative;
  top: -1px;
  left: 4px;
}

.alc__summary__reset {
  display: inline-block;
}

.alc__summary__reset__button {
  padding: 5px 10px;
  border-radius: 3px;
  border: 1px solid rgba(0, 0, 0, .35);
  background: #00676a;
  color: white;
  font-size: 13px;
}

.alc__summary__reset__icon {
  position: relative;
  top: -1px;
  left: 4px;
}
